DatabaseManager class

Constructors

DatabaseManager()
factory

Properties

databases ↔ List<UMEDatabase>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hiveHelper ↔ HiveHelper
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedPreferencesHelper ↔ SharedPreferencesHelper
getter/setter pair
sqliteHelper ↔ SqliteHelper
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDatabases({required List<UMEDatabase> databases}) → Future<void>
使用hive数据库 路径可以为空
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited