HiveDatabase class

Implemented types

Constructors

HiveDatabase(List<HiveBoxItem<UMEHiveData>> boxItems)

Properties

boxItems ↔ List<HiveBoxItem<UMEHiveData>>
hive需要打开的盒子
getter/setter pair
databaseName → String
no setteroverride
databasePath → String?
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteDB() → bool
每次清空db数据和文件
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited