HiveTableData<T extends UMEHiveData> class

Implemented types

Constructors

HiveTableData(String _tableName, {required Box<UMEHiveData> box})

Properties

box → Box<UMEHiveData>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tableName() → String
if it is sqlite the table name or if it is hive the box name or objectdb the name
override
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited