SqliteTableColumData class

Implemented types

Constructors

SqliteTableColumData({required int cid, required dynamic dfltValue, required String type, required String name, required int? notnull, required int? pk})

Properties

cid → int
final
dfltValue → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
notnull → int?
final
pk → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

columnName() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited