SqliteTableData class

sqlite data

Implemented types

Constructors

SqliteTableData(String _tableName, {String? createSql, int rootpage = 0, String? name, String? type, required List<SqliteTableColumData> columnData})

Properties

columnData → List<SqliteTableColumData>
final
createSql → String?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
rootpage → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tableName() → String
if it is sqlite the table name or if it is hive the box name or objectdb the name
override
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited